use std::ops::Deref;

use rocket::{http::CookieJar, State};
use rocket_dyn_templates::{context, Template};

use crate::{
    cookies::LANG_COOKIE,
    i18n::DEFAULT as DEFAULT_LANG,
    models::{Challenge, Settings, User},
    utils::AcceptLanguage,
};

#[get("/<challenge>")]
pub async fn get_challenge(
    challenge: u32,
    cookies: &CookieJar<'_>,
    settings: &State<Settings>,
    accept_language: AcceptLanguage,
) -> Template {
    Template::render(
        "index",
        context! {
            challenge,
            settings: settings.deref(),
            lang: cookies
                .get(LANG_COOKIE)
                .map(|cookie| vec![cookie.value().to_owned()])
                .or(accept_language.0)
                .unwrap_or_else(|| vec![DEFAULT_LANG.to_owned()]),
            user: User::get(cookies).await.unwrap(),
            content: Challenge::get(challenge),
        },
    )
}
